Crate dnet_utils

Crate dnet_utils 

Transport-related utilities.

Modules

channelchannel
Transport for communication over futures channels.
filterfiltering
Filtering incoming and/or outgoing messages.
latestlatest
Wrapper transport turning a numbered transport into a transport discarding old messages.
mapmapping
Mapping transports into other message types.
mergemerged
Merge Sink and Stream into a dnet transport.
numbernumbered
Wrapper transport attaching a number to messages.
pipepipe
Pipe messages from one transport into another and vice versa.
splitsplitting
Splitting transport into multiple transports of different message types.
unwrapunwrapping
Unwrapping incoming messages.
voidvoid
Transport sending messages into the void, never receiving any messages.
wallwall
Transport that rejects every operation.

Traits

ConditionalSendWebAssembly
Send on native targets, empty trait on WASM.