Module pipe

Module pipe 

Pipe messages from one transport into another and vice versa.

Structs

DefaultReceiveErrorCallback
Default ReceiveErrorCallback.
DefaultSendErrorCallback
Default SendErrorCallback.
ErrorHandler
Pipe message passing error handler.
Pipe
Pipe sending messages from one transport into another and vice versa.

Enums

ErrorHandlingStrategy
Strategy of handling message passing errors.

Traits

Error
Helper trait for pipe-able transport error.
Message
Helper trait for pipe-able transport message.
ReceiveErrorCallback
Callback called when an error is encountered while trying to receive a message from the transport.
SendErrorCallback
Callback called when an error is encountered while trying to send a message through the transport.
Transport
Helper trait for transports that can be piped.

Functions

pipe
Pipe messages from one transport into another and vice versa.