ErrorHandler

Struct ErrorHandler 

pub struct ErrorHandler<Message, Error> {
    pub send_error_callback: Box<dyn SendErrorCallback<Message, Error>>,
    pub receive_error_callback: Box<dyn ReceiveErrorCallback<Error>>,
}
Available on crate feature pipe only.
Pipe message passing error handler.

Fields

send_error_callback: Box<dyn SendErrorCallback<Message, Error>>

Callback called when an error is encountered while trying to send a message through the transport.

receive_error_callback: Box<dyn ReceiveErrorCallback<Error>>

Callback called when an error is encountered while trying to receive a message from the transport.

Implementations

Source

impl<Message, Error> ErrorHandler<Message, Error>

pub fn new<S, R>(send_error_callback: S, receive_error_callback: R) -> Self
where S: SendErrorCallback<Message, Error>, R: ReceiveErrorCallback<Error>,

Create new error handler.