Module split

Module split 

Available on crate feature splitting only.
Splitting transport into multiple transports of different message types.

Structs

Part
One of the transports after split.

Enums

Error
Part transport error.
Message
Wrapping message of split transport.

Traits

Split2
Trait allowing transports to be split into two of different message types.
Split3
Trait allowing transports to be split into three of different message types.
Split4
Trait allowing transports to be split into four of different message types.
Split5
Trait allowing transports to be split into five of different message types.