Module void

Module void 

Available on crate feature void only.
Transport sending messages into the void, never receiving any messages.

Structs

Void
Transport sending messages into the void, never receiving any messages.