Transport-related utilities.
Modules
- channel
channel - Transport for communication over futures channels.
- filter
filtering - Filtering incoming and/or outgoing messages.
- latest
latest - Wrapper transport turning a numbered transport into a transport discarding old messages.
- map
mapping - Mapping transports into other message types.
- merge
merged - Merge Sink and Stream into a
dnettransport. - number
numbered - Wrapper transport attaching a number to messages.
- pipe
pipe - Pipe messages from one transport into another and vice versa.
- split
splitting - Splitting transport into multiple transports of different message types.
- unwrap
unwrapping - Unwrapping incoming messages.
- void
void - Transport sending messages into the void, never receiving any messages.
- wall
wall - Transport that rejects every operation.
Traits
- Conditional
Send WebAssembly - Send on native targets, empty trait on WASM.