Crate dnet_utils

Crate dnet_utils 

Transport-related utilities.

Modules

channel
Transport for communication over futures channels.
filter
Filtering incoming and/or outgoing messages.
latest
Wrapper transport turning a numbered transport into a transport discarding old messages.
map
Mapping transports into other message types.
merge
Merge Sink and Stream into a dnet transport.
number
Wrapper transport attaching a number to messages.
pipe
Pipe messages from one transport into another and vice versa.
split
Splitting transport into multiple transports of different message types.
unwrap
Unwrapping incoming messages.
void
Transport sending messages into the void, never receiving any messages.
wall
Transport that rejects every operation.