Wrapper transport turning a numbered transport into a transport discarding old messages.
Polling a transport for the next message will return the latest received message, ignoring messages received before.
Potentially useful when user doesn’t care about stale messages (for example: multiplayer video games).
Structs
- Latest
- Wrapper transport turning a numbered transport into a transport discarding old messages (polling a transport for the next message will return the latest received message, ignoring messages received before).
Traits
- Only
Latest - Trait for requesting only the most recent messages.