pub trait OnlyLatest<N, Incoming, Outgoing, Error>:
Transport<Incoming, Outgoing, Error>
+ Sized
+ Unpinwhere
Error: Error,{
// Provided method
fn only_latest(self) -> Latest<Self, Error, N, Incoming, Outgoing>
where Incoming: Number<Output = N>,
for<'a> &'a N: PartialOrd { ... }
}Expand description
Trait for requesting only the most recent messages.
Provided Methods
Sourcefn only_latest(self) -> Latest<Self, Error, N, Incoming, Outgoing>
fn only_latest(self) -> Latest<Self, Error, N, Incoming, Outgoing>
Wrap transport with Latest transport turning it into transport returning latest message when polling it for the next received message.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".