Pipe messages from one transport into another and vice versa.
Structs
- Default
Receive Error Callback - Default ReceiveErrorCallback.
- Default
Send Error Callback - Default SendErrorCallback.
- Error
Handler - Pipe message passing error handler.
- Pipe
- Pipe sending messages from one transport into another and vice versa.
Enums
- Error
Handling Strategy - Strategy of handling message passing errors.
Traits
- Error
- Helper trait for pipe-able transport error.
- Message
- Helper trait for pipe-able transport message.
- Receive
Error Callback - Callback called when an error is encountered while trying to receive a message from the transport.
- Send
Error Callback - Callback called when an error is encountered while trying to send a message through the transport.
- Transport
- Helper trait for transports that can be piped.
Functions
- pipe
- Pipe messages from one transport into another and vice versa.