Module void
dnet_
utils
0.1.1
Module void
Module Items
Structs
In crate dnet_
utils
dnet_utils
Module
void
Available on
crate feature
void
only.
Transport sending messages into the void, never receiving any messages.
Structs

Void
Transport sending messages into the void, never receiving any messages.